# Objects Package

This section documents the core simulation objects and their management in the package.

## Contents

- [Base Class](object.md) - Core object classes and positioning constraints
- [Boundaries](boundaries.md) - Simulation Boundaries
- [Detectors](detectors.md) - Detectors for measuring physical metrics during simulation
- [Devices](boundaries.md) - Devices with a variable shape that can be optimized
- [Sources](sources.md) - Source objects for inducing light into a simulation
- [Static Material](static_material.md) - Objects with more intricate shapes than the default cuboid
